Learn R Programming

klsh (version 0.1.0)

bag_of_word_ify: Function to convert a record into a bag of tokens with a fieldwise flag

Description

Function to convert a record into a bag of tokens with a fieldwise flag

Usage

bag_of_word_ify(record, k, fieldwise = FALSE)

Arguments

record

String or record

k

Parameter k, which is the number of shingle, tokens, or grams to break the string into

fieldwise

Flag where the defalt setting to include the record as the entire string

Value

Computes the bag of tokens for a string

Examples

Run this code
# NOT RUN {
data(RLdata500)
data.500 <- RLdata500[-c(2,4)]
bag_of_word_ify(data.500[1,c(-2)],k=2)
bag_of_word_ify(data.500[300,c(-2)],k=2)
names(bag_of_word_ify(data.500[300,c(-2)],k=2))
# }

Run the code above in your browser using DataLab