powered by
Function that reduces a bag of words into a signature matrix using multiple random projections
bag_signatures(sack_of_bags, p, weighting_table)
Sack of bag of words
Number of random projections p
Weighting table (inverse document frequency)
Computes a signature matrix using multiple random projections and the inverse document frequency weights
# NOT RUN { data(RLdata500) data.500 <- RLdata500[-c(2,4)] sack <- sacks_of_bags_of_words(data.500[1:3,c(-2)],k=2) idf <- calc_idf(sack) bag_signatures(sack, p=5, idf) # }
Run the code above in your browser using DataLab