powered by
Function that reduces a bag of words into a signature matrix using multiple random projections
klsh(r.set, p, num.blocks, k, fieldwise = FALSE, quiet = TRUE)
Set of records
Number of random projections p
The total number of desired blocks
The total number of tokens
Flag with default FALSE
Flag to turn on printed progress, default to TRUE
The blocks from performing KLSH
# NOT RUN { data(RLdata500) data.500 <- RLdata500[-c(2,4)] klsh.blocks <- klsh(data.500, p=20, num.blocks=5, k=2) # }
Run the code above in your browser using DataLab