Learn R Programming

klsh (version 0.1.0)

reduction.ratio: Returns the reduction ratio associated with a blocking method

Description

Returns the reduction ratio associated with a blocking method

Usage

reduction.ratio(block.labels)

Arguments

block.labels

A list of the blocks labels.

Value

The reduction ratio

Examples

Run this code
# NOT RUN {
data("RLdata500")
klsh.blocks <- klsh(RLdata500, p=20, num.blocks=5, k=2)
block.ids <- block.ids.from.blocking(klsh.blocks)
reduction.ratio(block.ids)
# }

Run the code above in your browser using DataLab