powered by
Function to convert all records into a bag of tokens
sacks_of_bags_of_words(r.set, k, fieldwise = FALSE)
Record set
Parameter k, which is the number of shingle, tokens, or grams to break the string into
Flag where the defalt setting to include the record as the entire string
Computes the bag of tokens for a record set
# NOT RUN { data(RLdata500) data.500 <- RLdata500[-c(2,4)] sacks_of_bags_of_words(data.500[1:3,c(-2)],k=2) # }
Run the code above in your browser using DataLab